@@ -256,7 +256,8 @@ class GAN():
             save_ckpt=5,
             verbose=1,
             max_outputs=2,
-            initial_step=0):
+            initial_step=0,
+            mlflow=False):
         """Trains both models for n EPOCHS. Saves ckpts every n EPOCHS.
         The training loop together with the optimization algorithm define the
         learning algorithm.
@@ -279,6 +280,8 @@ class GAN():
         """
         if self.generator_optimizer is None:
             raise ModelNotCompiledError("use GAN.compile() first.")
+        if mlflow:
+            import mlflow
 
         # Retrace workaround @function signature only tensors.
         step = tf.Variable(initial_step, name="step", dtype=tf.int64)
@@ -305,6 +308,8 @@ class GAN():
                 print("\nSaving checkpoint for epoch {} at {}".format(
                     epoch + 1, ckpt_save_path))
 
+            #if mlflow: TODO
+            #    mlflow.log_metric("")
             print(" - Epoch {} finished in {} sec\n".format(
                 epoch + 1, int(time.time() - start)))
 
